@@ -159,6 +159,10 @@ module KDE
 		end
 	end
 
+	class Archive < Qt::Base
+		UnknownTime = Qt::Enum.new(-1, "KArchive")
+	end
+
 	class ArchiveEntry < Qt::Base
 		def name(*args)
 			method_missing(:name, *args)
@@ -324,7 +328,7 @@ module KDE
 	end
 
 	class File < Qt::Base
-		File = 1
+		File = Qt::Enum.new(1, "KFile::Mode")
 	end
 
 	class FileItem < Qt::Base
